@@ -2,6 +2,7 @@
 
 require 'stringio'
 require 'io/wait'
+require 'track_open_instances'
 
 module ProcessExecuter
   # Write data sent through a pipe to a destination
@@ -41,6 +42,8 @@ module ProcessExecuter
   # @api public
   #
   class MonitoredPipe
+    include TrackOpenInstances
+
     # Create a new monitored pipe
     #
     # Creates a IO.pipe and starts a monitoring thread to read data written to the pipe.
@@ -64,6 +67,8 @@ module ProcessExecuter
       @pipe_reader, @pipe_writer = IO.pipe
       @state = :open
       @thread = start_monitoring_thread
+
+      self.class.add_open_instance(self)
     end
 
     # Set the state to `:closing` and wait for the state to be set to `:closed`
@@ -83,18 +88,15 @@ module ProcessExecuter
     #
     def close
       mutex.synchronize do
-        return unless state == :open
-
-        @state = :closing
-      end
-
-      mutex.synchronize do
-        condition_variable.wait(mutex) while @state != :closed
+        if state == :open
+          @state = :closing
+          condition_variable.wait(mutex) while @state != :closed
+        end
       end
 
       thread.join
-
       destination.close
+      self.class.remove_open_instance(self)
     end
 
     # Return the write end of the pipe so that data can be written to it
